@@ -3,6 +3,7 @@
 import logging
 import os
 import pickle
+import shutil
 import sys
 import time
 
@@ -13,19 +14,19 @@ from .utils import (get_correct_answer, ask_yes_no, path_fixer,
 
 # framework stuff
 from not_so_tuf import NotSoTuf
+from not_so_tuf.client import Client
 from not_so_tuf.package_handler import PackageHandler
 from not_so_tuf.key_handler import KeyHandler
 from not_so_tuf.uploader import Uploader
 from not_so_tuf.utils import FileCrypt, _cwd
+from not_so_tuf.version import __version__
 
-log = logging.getLogger()
+
+log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
-format_str = '[%(relativeCreated)d] %(name)s  %(levelname)s: %(message)s'
-fh_formatter = logging.Formatter(format_str)
-fh = logging.FileHandler('nst.log', mode='a')
-fh.setFormatter(fh_formatter)
-fh.setLevel(logging.INFO)
-log.addHandler(fh)
+h = logging.NullHandler()
+h.setLevel(logging.DEBUG)
+log.addHandler(h)
 
 
 class Ui(object):
@@ -111,10 +112,10 @@ class Ui(object):
         answer2 = False
         answer3 = False
 
-        if answer1 is True or answer2 is True or answer3 is True:
+        if answer1 or answer2 or answer3:
             self.config.REMOTE_DIR = get_correct_answer('Enter remote dir',
                                                         required=True)
-        if answer1 is True or answer2 is True:
+        if answer1 or answer2:
             self.config.HOST = get_correct_answer('Enter host', required=True)
 
         if answer1:
@@ -154,6 +155,7 @@ class Ui(object):
         print app_header('Settings')
         options = [('View Settings', self.view_settings),
                    ('Update Settings', self.update_settings),
+                   ('Decrypt and Copy Config', self.copy_decrypted_config),
                    ('Go Back', self.main)]
 
         next = menu_options(options)
@@ -227,8 +229,7 @@ class Ui(object):
     def save_config(self, obj):
         self.nst.update_config(obj)
         log.debug('Saving Config')
-        cwd = _cwd
-        filename = os.path.join(cwd, 'config.data')
+        filename = os.path.join(_cwd, 'config.data')
         fc = FileCrypt(filename)
         fc.decrypt()
         with open(filename, 'w') as f:
@@ -237,8 +238,7 @@ class Ui(object):
 
     def load_config(self):
         log.debug('Loading Config')
-        cwd = _cwd
-        filename = os.path.join(cwd, 'config.data')
+        filename = os.path.join(_cwd, 'config.data')
         fc = FileCrypt(filename)
         fc.decrypt()
         with open(filename, 'r') as f:
@@ -246,6 +246,21 @@ class Ui(object):
         fc.encrypt()
         return config_data
 
+    def copy_decrypted_config(self):
+        log.debug('Attempting to copy decrypted config')
+        filename = os.path.join(_cwd, 'config.data')
+        fc = FileCrypt(filename)
+        fc.decrypt()
+        try:
+            shutil.copy(filename, filename + ' copy')
+        except Exception as e:
+            log.error(str(e), exc_info=True)
+            log.error('Cannot copy decrypted config file')
+        fc.encrypt()
+        msg = 'Decrypted config file copied.  Press enter to continue'
+        raw_input(format_msg(msg))
+        self.settings()
+
     def sign_updates(self):
         log.debug('Sign Updates Menu')
         print app_header('Sign Updates')
@@ -327,10 +342,28 @@ class Ui(object):
         self.main()
 
 
+class ClientConfig(object):
+
+    UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
+    PUBLIC_KEY = (16464922665638673681992463013273935612664219094906980149897613483558764958275503471833999796774944451919679352299199781040261183626243789235159282484489660866211751942888040512642103075255732190154437871072326800313353343988071645793491504044388864374910418983325794095950121251375913490389709129928619827303368362856224581261135920008510653620012541583622789200202174035822993035846677533547389325544764270670429010858826140320098873827212627840823767544126373206301938873536107735052145489782939917808169280407467079055393335221958452100971113008041835393071679231080475062804424979544387709688694450412240360063013L, 65537)
+
+
 def main():
     try:
-        ui = Ui()
-        ui.start()
-    except KeyboardInterrupt:
-        # ToDo: Add clean up stuff here
-        print '\n\nExited by user'
+        if getattr(sys, 'frozen', False):
+            nst = NotSoTuf(__name__, ClientConfig())
+            client = Client(nst)
+            print 'Current Version {}'.format(__version__)
+            print '\nChecking for updates...'
+            update = client.update_check('Not So TUF', __version__)
+            if update:
+                print 'About to install update and restart'
+                client.install_restart()
+        try:
+            ui = Ui()
+            ui.start()
+        except KeyboardInterrupt:
+            # ToDo: Add clean up stuff here
+            print '\n\nExited by user'
+    except Exception as e:
+        log.error(str(e), exc_info=True)
