@@ -78,7 +78,7 @@ class KeyHandler(object):
         public = os.path.join(self.keys_dir, self.public_key_name)
         private = os.path.join(self.keys_dir, self.private_key_name)
         if os.path.exists(public) and os.path.exists(private):
-            if overwrite is False:
+            if not overwrite:
                 log.info('Cannot overwrite old key files.')
                 log.debug('Pass overwrite=True to make_keys to overwrite')
                 return
