@@ -1,10 +1,12 @@
 # Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
 
-import bsdiff4
+try:
+    import bsdiff4
+except ImportError:
+    bsdiff4 = None
 import hashlib
 import logging
 import os
-import sys
 
 from .file_downloader import FileDownloader
 from .utils import (ChDir, _version_string_to_tuple,
